==> eiffelstudio-18.01.10.1424.tar: F_code/C10/ir494.c <==
/*
 * Code for class IRON_WORKING_COPY_REPOSITORY
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "ir494.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {IRON_WORKING_COPY_REPOSITORY}.make */
void F1047_8235 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(4);
	RTLR(0,loc1);
	RTLR(1,tr1);
	RTLR(2,arg1);
	RTLR(3,Current);
	RTLIU(4);
	
	RTEAA("make", 1046, Current, 1, 1, 12014);
	RTGC;
	RTHOOK(1);
	tr1 = RTLNS(eif_new_type(1042, 0x00).id, 1042, _OBJSIZ_1_1_0_3_0_0_0_0_);
	F1043_8085(RTCW(tr1), arg1);
	loc1 = (EIF_REFERENCE) tr1;
	RTHOOK(2);
	F1047_8247(Current, loc1);
	RTHOOK(3);
	tr1 = RTLNS(eif_new_type(1057, 0x00).id, 1057, _OBJSIZ_2_1_0_0_0_0_0_0_);
	F1058_8510(RTCW(tr1), loc1);
	F1047_8236(Current, tr1);
	RTHOOK(4);
	RTLE;
	RTEE;
}

/* {IRON_WORKING_COPY_REPOSITORY}.make_from_path */
void F1047_8236 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(3);
	RTLR(0,Current);
	RTLR(1,arg1);
	RTLR(2,tr1);
	RTLIU(3);
	
	RTEAA("make_from_path", 1046, Current, 0, 1, 12015);
	RTGC;
	RTHOOK(1);
	RTAR(Current, arg1);
	*(EIF_REFERENCE *)(Current + _REFACS_1_) = (EIF_REFERENCE) arg1;
	RTHOOK(2);
	tr1 = F1047_8248(Current, arg1);
	RTAR(Current, tr1);
	*(EIF_REFERENCE *)(Current + _REFACS_2_) = (EIF_REFERENCE) tr1;
	RTHOOK(3);
	F795_6527(Current);
	RTHOOK(4);
	RTLE;
	RTEE;
}

/* {IRON_WORKING_COPY_REPOSITORY}.make_from_uri */
void F1047_8237 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_BOOLEAN tb1;
	RTLD;
	
	RTLI(6);
	RTLR(0,Current);
	RTLR(1,arg1);
	RTLR(2,loc1);
	RTLR(3,tr1);
	RTLR(4,tr2);
	RTLR(5,loc2);
	RTLIU(6);
	
	RTEAA("make_from_uri", 1046, Current, 2, 1, 12016);
	RTGC;
	RTHOOK(1);
	RTAR(Current, arg1);
	*(EIF_REFERENCE *)(Current + _REFACS_2_) = (EIF_REFERENCE) arg1;
	RTHOOK(2);
	tr1 = RTLNS(eif_new_type(1297, 0x00).id, 1297, _OBJSIZ_7_3_0_1_0_0_0_0_);
	F1298_12116(RTCW(tr1), arg1);
	loc1 = (EIF_REFERENCE) tr1;
	RTHOOK(3);
	tr1 = RTLNS(eif_new_type(1297, 0x00).id, 1297, _OBJSIZ_7_3_0_1_0_0_0_0_);
	tr2 = *(EIF_REFERENCE *)(RTCW(loc1) + _REFACS_6_);
	F1298_12117(RTCW(tr1), tr2);
	loc1 = (EIF_REFERENCE) tr1;
	RTHOOK(4);
	RTAR(Current, loc1);
	*(EIF_REFERENCE *)(Current + _REFACS_2_) = (EIF_REFERENCE) loc1;
	RTHOOK(5);
	tr1 = *(EIF_REFERENCE *)(RTCW(loc1) + _REFACS_6_);
	RTAR(Current, tr1);
	*(EIF_REFERENCE *)(Current + _REFACS_1_) = (EIF_REFERENCE) tr1;
	RTHOOK(6);
	tr1 = *(EIF_REFERENCE *)(RTCW(arg1) + _REFACS_3_);
	tb1 = F1037_7883(RTCW(tr1), (EIF_CHARACTER_8) '$');
	if (tb1) {
		RTHOOK(7);
		tr1 = RTLNS(eif_new_type(1042, 0x00).id, 1042, _OBJSIZ_1_1_0_3_0_0_0_0_);
		tr2 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
		tr2 = F1058_8549(RTCW(tr2));
		F1041_8014(RTCW(tr1), tr2);
		loc2 = (EIF_REFERENCE) tr1;
		RTHOOK(8);
		F1047_8247(Current, loc2);
		RTHOOK(9);
		tr1 = RTLNSMART(eif_new_type(1057, 0).id);
		F1058_8510(RTCW(tr1), loc2);
		RTAR(Current, tr1);
		*(EIF_REFERENCE *)(Current + _REFACS_1_) = (EIF_REFERENCE) tr1;
	} else {
		RTHOOK(10);
		tr1 = RTLNS(eif_new_type(1297, 0x00).id, 1297, _OBJSIZ_7_3_0_1_0_0_0_0_);
		F1298_12116(RTCW(tr1), arg1);
		loc1 = (EIF_REFERENCE) tr1;
		RTHOOK(11);
		tr1 = *(EIF_REFERENCE *)(RTCW(loc1) + _REFACS_6_);
		RTAR(Current, tr1);
		*(EIF_REFERENCE *)(Current + _REFACS_1_) = (EIF_REFERENCE) tr1;
	}
	RTHOOK(12);
	F795_6527(Current);
	RTHOOK(13);
	RTLE;
	RTEE;
}

/* {IRON_WORKING_COPY_REPOSITORY}.create_available_packages */
void F1047_8238 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTEAA("create_available_packages", 1046, Current, 0, 0, 12017);
	RTGC;
	RTHOOK(1);
	tr1 = RTLNSMART(eif_final_id(Y5695,Y5695_gen_type,Dftype(Current),794).id);
	F910_6918(RTCW(tr1), ((EIF_INTEGER_32) 0L));
	RTAR(Current, tr1);
	*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) tr1;
	RTHOOK(2);
	RTLE;
	RTEE;
}

/* {IRON_WORKING_COPY_REPOSITORY}.path */
EIF_REFERENCE F1047_8239 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current + _REFACS_1_);
}


/* {IRON_WORKING_COPY_REPOSITORY}.location */
EIF_REFERENCE F1047_8240 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current + _REFACS_2_);
}


/* {IRON_WORKING_COPY_REPOSITORY}.available_packages */
EIF_REFERENCE F1047_8242 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current);
}


/* {IRON_WORKING_COPY_REPOSITORY}.is_same_repository */
EIF_BOOLEAN F1047_8243 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
	
	RTLD;
	
	RTLI(5);
	RTLR(0,loc1);
	RTLR(1,arg1);
	RTLR(2,Current);
	RTLR(3,tr1);
	RTLR(4,tr2);
	RTLIU(5);
	
	RTEAA("is_same_repository", 1046, Current, 1, 1, 12022);
	RTGC;
	RTHOOK(1);
	loc1 = arg1;
	loc1 = RTRV(eif_new_type(1046, 0x00),loc1);
	if (EIF_TEST(loc1)) {
		RTHOOK(2);
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
		tr1 = F1058_8531(RTCW(tr1));
		tr1 = F1058_8549(RTCW(tr1));
		tr2 = *(EIF_REFERENCE *)(loc1 + _REFACS_1_);
		tr2 = F1058_8531(RTCW(tr2));
		tr2 = F1058_8549(RTCW(tr2));
		Result = F1041_8038(RTCW(tr1), tr2);
	}
	RTHOOK(3);
	RTLE;
	RTEE;
	return Result;
}

/* {IRON_WORKING_COPY_REPOSITORY}.expand_variables */
void F1047_8247 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	struct eif_ex_12 sloc1;
	EIF_REFERENCE loc1 = (EIF_REFERENCE) sloc1.data;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_REFERENCE tr3 = NULL;
	EIF_REFERENCE tr4 = NULL;
	RTCFDT;
	RTLD;
	
	memset (&sloc1.overhead, 0, OVERHEAD + _OBJSIZ_0_0_0_0_0_0_0_0_);
	sloc1.overhead.ov_flags = EO_EXP | EO_STACK;
	RT_DFS(&sloc1.overhead, eif_new_type(17, 0x00).id);
	RTLI(7);
	RTLR(0,loc1);
	RTLR(1,arg1);
	RTLR(2,Current);
	RTLR(3,tr1);
	RTLR(4,tr2);
	RTLR(5,tr3);
	RTLR(6,tr4);
	RTLIU(7);
	
	RTEAA("expand_variables", 1046, Current, 1, 1, 12011);
	RTGC;
	RTHOOK(1);
	{
		static EIF_TYPE_INDEX typarr0[] = {0xFFF9,1,980,641,0xFFFF};
		EIF_TYPE typres0;
		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
		
		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(dftype, typarr0)));
		tr1 = RTLNTS(typres0.id, 2, 0);
	}
	tr2 = RTOUCR(409,F664_5843,(Current));
	((EIF_TYPED_VALUE *)tr1+1)->it_r = tr2;
	RTAR(tr1,tr2);
	
	{
		static EIF_TYPE_INDEX typarr0[] = {1029,0xFFF9,1,980,1033,1042,0xFFFF};
		EIF_TYPE typres0;
		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
		
		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(dftype, typarr0)));
		tr4 = RTLNRF(typres0.id, (EIF_POINTER) __A361_40_2, (EIF_POINTER) _A361_40_2, (EIF_POINTER)(F642_4990),tr1, 1, 1);
	}
	F18_155(RTCW(loc1), arg1, tr4);
	RTHOOK(2);
	RTLE;
	RTEE;
}

/* {IRON_WORKING_COPY_REPOSITORY}.uri_location_from_path */
EIF_REFERENCE F1047_8248 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(4);
	RTLR(0,loc1);
	RTLR(1,tr1);
	RTLR(2,arg1);
	RTLR(3,Current);
	RTLIU(4);
	
	RTEAA("uri_location_from_path", 1046, Current, 1, 1, 12012);
	RTGC;
	RTHOOK(1);
	tr1 = RTLNS(eif_new_type(1297, 0x00).id, 1297, _OBJSIZ_7_3_0_1_0_0_0_0_);
	F1298_12117(RTCW(tr1), arg1);
	loc1 = (EIF_REFERENCE) tr1;
	RTHOOK(2);
	RTHOOK(3);
	RTLE;
	RTEE;
	return (EIF_REFERENCE) loc1;
}

void EIF_Minit494 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif

==> eiffelstudio-18.07.10.1981.tar: F_code/C10/ir494.c <==
/*
 * Code for class IRON_WORKING_COPY_REPOSITORY
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "ir494.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {IRON_WORKING_COPY_REPOSITORY}.make */
void F1075_9761 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(4);
	RTLR(0,loc1);
	RTLR(1,tr1);
	RTLR(2,arg1);
	RTLR(3,Current);
	RTLIU(4);
	
	RTEAA("make", 1074, Current, 1, 1, 13545);
	RTGC;
	RTHOOK(1);
	tr1 = RTLNS(eif_new_type(1066, 0x00).id, 1066, _OBJSIZ_1_1_0_3_0_0_0_0_);
	F1067_9457(RTCW(tr1), arg1);
	loc1 = (EIF_REFERENCE) tr1;
	RTHOOK(2);
	F1075_9773(Current, loc1);
	RTHOOK(3);
	tr1 = RTLNS(eif_new_type(1085, 0x00).id, 1085, _OBJSIZ_2_1_0_0_0_0_0_0_);
	F1086_10151(RTCW(tr1), loc1);
	F1075_9762(Current, tr1);
	RTHOOK(4);
	RTLE;
	RTEE;
}

/* {IRON_WORKING_COPY_REPOSITORY}.make_from_path */
void F1075_9762 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(3);
	RTLR(0,Current);
	RTLR(1,arg1);
	RTLR(2,tr1);
	RTLIU(3);
	
	RTEAA("make_from_path", 1074, Current, 0, 1, 13546);
	RTGC;
	RTHOOK(1);
	RTAR(Current, arg1);
	*(EIF_REFERENCE *)(Current + _REFACS_1_) = (EIF_REFERENCE) arg1;
	RTHOOK(2);
	tr1 = F1075_9774(Current, arg1);
	RTAR(Current, tr1);
	*(EIF_REFERENCE *)(Current + _REFACS_2_) = (EIF_REFERENCE) tr1;
	RTHOOK(3);
	F801_7481(Current);
	RTHOOK(4);
	RTLE;
	RTEE;
}

/* {IRON_WORKING_COPY_REPOSITORY}.make_from_uri */
void F1075_9763 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_BOOLEAN tb1;
	RTLD;
	
	RTLI(6);
	RTLR(0,Current);
	RTLR(1,arg1);
	RTLR(2,loc1);
	RTLR(3,tr1);
	RTLR(4,tr2);
	RTLR(5,loc2);
	RTLIU(6);
	
	RTEAA("make_from_uri", 1074, Current, 2, 1, 13547);
	RTGC;
	RTHOOK(1);
	RTAR(Current, arg1);
	*(EIF_REFERENCE *)(Current + _REFACS_2_) = (EIF_REFERENCE) arg1;
	RTHOOK(2);
	tr1 = RTLNS(eif_new_type(1319, 0x00).id, 1319, _OBJSIZ_7_3_0_1_0_0_0_0_);
	F1320_13782(RTCW(tr1), arg1);
	loc1 = (EIF_REFERENCE) tr1;
	RTHOOK(3);
	tr1 = RTLNS(eif_new_type(1319, 0x00).id, 1319, _OBJSIZ_7_3_0_1_0_0_0_0_);
	tr2 = *(EIF_REFERENCE *)(RTCW(loc1) + _REFACS_6_);
	F1320_13783(RTCW(tr1), tr2);
	loc1 = (EIF_REFERENCE) tr1;
	RTHOOK(4);
	RTAR(Current, loc1);
	*(EIF_REFERENCE *)(Current + _REFACS_2_) = (EIF_REFERENCE) loc1;
	RTHOOK(5);
	tr1 = *(EIF_REFERENCE *)(RTCW(loc1) + _REFACS_6_);
	RTAR(Current, tr1);
	*(EIF_REFERENCE *)(Current + _REFACS_1_) = (EIF_REFERENCE) tr1;
	RTHOOK(6);
	tr1 = *(EIF_REFERENCE *)(RTCW(arg1) + _REFACS_3_);
	tb1 = F1068_9582(RTCW(tr1), (EIF_CHARACTER_8) '$');
	if (tb1) {
		RTHOOK(7);
		tr1 = RTLNS(eif_new_type(1066, 0x00).id, 1066, _OBJSIZ_1_1_0_3_0_0_0_0_);
		tr2 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
		tr2 = F1086_10190(RTCW(tr2));
		F1065_9386(RTCW(tr1), tr2);
		loc2 = (EIF_REFERENCE) tr1;
		RTHOOK(8);
		F1075_9773(Current, loc2);
		RTHOOK(9);
		tr1 = RTLNSMART(eif_new_type(1085, 0).id);
		F1086_10151(RTCW(tr1), loc2);
		RTAR(Current, tr1);
		*(EIF_REFERENCE *)(Current + _REFACS_1_) = (EIF_REFERENCE) tr1;
	} else {
		RTHOOK(10);
		tr1 = RTLNS(eif_new_type(1319, 0x00).id, 1319, _OBJSIZ_7_3_0_1_0_0_0_0_);
		F1320_13782(RTCW(tr1), arg1);
		loc1 = (EIF_REFERENCE) tr1;
		RTHOOK(11);
		tr1 = *(EIF_REFERENCE *)(RTCW(loc1) + _REFACS_6_);
		RTAR(Current, tr1);
		*(EIF_REFERENCE *)(Current + _REFACS_1_) = (EIF_REFERENCE) tr1;
	}
	RTHOOK(12);
	F801_7481(Current);
	RTHOOK(13);
	RTLE;
	RTEE;
}

/* {IRON_WORKING_COPY_REPOSITORY}.create_available_packages */
void F1075_9764 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTEAA("create_available_packages", 1074, Current, 0, 0, 13548);
	RTGC;
	RTHOOK(1);
	tr1 = RTLNSMART(eif_final_id(Y6051,Y6051_gen_type,Dftype(Current),800).id);
	(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_INTEGER_32)) R6305[Dtype(tr1)-925])(RTCW(tr1), ((EIF_INTEGER_32) 0L));
	RTAR(Current, tr1);
	*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) tr1;
	RTHOOK(2);
	RTLE;
	RTEE;
}

/* {IRON_WORKING_COPY_REPOSITORY}.path */
EIF_REFERENCE F1075_9765 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current + _REFACS_1_);
}


/* {IRON_WORKING_COPY_REPOSITORY}.location */
EIF_REFERENCE F1075_9766 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current + _REFACS_2_);
}


/* {IRON_WORKING_COPY_REPOSITORY}.available_packages */
EIF_REFERENCE F1075_9768 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current);
}


/* {IRON_WORKING_COPY_REPOSITORY}.is_same_repository */
EIF_BOOLEAN F1075_9769 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
	
	RTLD;
	
	RTLI(5);
	RTLR(0,loc1);
	RTLR(1,arg1);
	RTLR(2,Current);
	RTLR(3,tr1);
	RTLR(4,tr2);
	RTLIU(5);
	
	RTEAA("is_same_repository", 1074, Current, 1, 1, 13538);
	RTGC;
	RTHOOK(1);
	loc1 = arg1;
	loc1 = RTRV(eif_new_type(1074, 0x00),loc1);
	if (EIF_TEST(loc1)) {
		RTHOOK(2);
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
		tr1 = F1086_10172(RTCW(tr1));
		tr1 = F1086_10190(RTCW(tr1));
		tr2 = *(EIF_REFERENCE *)(loc1 + _REFACS_1_);
		tr2 = F1086_10172(RTCW(tr2));
		tr2 = F1086_10190(RTCW(tr2));
		Result = F1065_9410(RTCW(tr1), tr2);
	}
	RTHOOK(3);
	RTLE;
	RTEE;
	return Result;
}

/* {IRON_WORKING_COPY_REPOSITORY}.expand_variables */
void F1075_9773 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	struct eif_ex_11 sloc1;
	EIF_REFERENCE loc1 = (EIF_REFERENCE) sloc1.data;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_REFERENCE tr3 = NULL;
	EIF_REFERENCE tr4 = NULL;
	RTCFDT;
	RTLD;
	
	memset (&sloc1.overhead, 0, OVERHEAD + _OBJSIZ_0_0_0_0_0_0_0_0_);
	sloc1.overhead.ov_flags = EO_EXP | EO_STACK;
	RT_DFS(&sloc1.overhead, eif_new_type(12, 0x00).id);
	RTLI(7);
	RTLR(0,loc1);
	RTLR(1,arg1);
	RTLR(2,Current);
	RTLR(3,tr1);
	RTLR(4,tr2);
	RTLR(5,tr3);
	RTLR(6,tr4);
	RTLIU(7);
	
	RTEAA("expand_variables", 1074, Current, 1, 1, 13542);
	RTGC;
	RTHOOK(1);
	{
		static EIF_TYPE_INDEX typarr0[] = {0xFFF9,1,1010,648,0xFFFF};
		EIF_TYPE typres0;
		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
		
		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(dftype, typarr0)));
		tr1 = RTLNTS(typres0.id, 2, 0);
	}
	tr2 = RTOSCF(6209,F657_6209,(Current));
	((EIF_TYPED_VALUE *)tr1+1)->it_r = tr2;
	RTAR(tr1,tr2);
	
	{
		static EIF_TYPE_INDEX typarr0[] = {1057,0xFFF9,1,1010,1061,1066,0xFFFF};
		EIF_TYPE typres0;
		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
		
		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(dftype, typarr0)));
		tr4 = RTLNRF(typres0.id, (EIF_POINTER) __A358_40_2, (EIF_POINTER) _A358_40_2, (EIF_POINTER)(F649_6052),tr1, 1, 1);
	}
	F13_197(RTCW(loc1), arg1, tr4);
	RTHOOK(2);
	RTLE;
	RTEE;
}

/* {IRON_WORKING_COPY_REPOSITORY}.uri_location_from_path */
EIF_REFERENCE F1075_9774 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(4);
	RTLR(0,loc1);
	RTLR(1,tr1);
	RTLR(2,arg1);
	RTLR(3,Current);
	RTLIU(4);
	
	RTEAA("uri_location_from_path", 1074, Current, 1, 1, 13543);
	RTGC;
	RTHOOK(1);
	tr1 = RTLNS(eif_new_type(1319, 0x00).id, 1319, _OBJSIZ_7_3_0_1_0_0_0_0_);
	F1320_13783(RTCW(tr1), arg1);
	loc1 = (EIF_REFERENCE) tr1;
	RTHOOK(2);
	RTHOOK(3);
	RTLE;
	RTEE;
	return (EIF_REFERENCE) loc1;
}

void EIF_Minit494 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif
